Welcome to mirror list, hosted at ThFree Co, Russian Federation.

dev.gajim.org/gajim/gajim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorJean-Marie Traissard <jim@lapin.org>2008-08-04 02:21:50 +0400
committerJean-Marie Traissard <jim@lapin.org>2008-08-04 02:21:50 +0400
commit94a43a03fb36f030ffafd054225b0f4fafa675f0 (patch)
treeebef9043d51934b88973577239081aa485740140 /src
parent6bd991882bc2681be08e4e962dee517bc9b25e0c (diff)
Update counting of online transports when a transport change status.
Diffstat (limited to 'src')
-rwxr-xr-xsrc/gajim.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/gajim.py b/src/gajim.py
index 04bf91907..04faa6352 100755
--- a/src/gajim.py
+++ b/src/gajim.py
@@ -791,8 +791,9 @@ class Interface:
if gajim.jid_is_transport(jid):
# It must be an agent
if ji in jid_list:
# Update existing iter
self.roster.draw_contact(ji, account)
+ self.roster.draw_group(_('Transports'), account)
if new_show > 1 and ji in \
gajim.transport_avatar[account]:
# transport just signed in.
@@ -791,8 +791,9 @@ class Interface:
# It must be an agent
if ji in jid_list:
- # Update existing iter
+ # Update existing iter and group counting
self.roster.draw_contact(ji, account)